psychopy_ext.exp.Task.before_block — psychopy_ext 0.5.4 documentation
Author: Jonas Kubilius
Description: A framework for a rapid reproducible design, analysis and plotting of experiments in neuroscience and psychology

# psychopy_ext.exp.Task.before_block

`Task.` `before_block`(text=None, auto=1, wait=0.5, wait_stim=None)

  Show text before the block starts.

  Will not show anything if there’s only one block.

  Kwargs: | text (str, default: None) Text to show. If None, defaults to showing block number. wait (float, default: .5) How long to wait after the end of showing instructions, in seconds. wait_stim (stimulus or a list of stimuli, default: None) During this waiting, which stimuli should be shown. Usually, it would be a fixation spot. If None, this fixation spot will be attempted to be drawn. auto (float, default: 1) Duration of time-out of the instructions screen, in seconds.